/*
 * Copyright (c) 2007 Kathryn Huxtable
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: RSASignatureTest.java 495 2007-03-31 14:55:20Z huxtable $
 */
package org.kathrynhuxtable.middleware.shibshim.util;

import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.TimeZone;

import junit.framework.TestCase;

/**
 * Test the TimeUtil class.
 */
public class TimeUtilTest extends TestCase {

    public void testTimeZero() {
        assertEquals("1970-01-01T00:00:00.000Z", TimeUtil.formatToGMT("0"));
    }

    public void testTime() {
        String time = "2007:12:11:12:31:53";
        GregorianCalendar cal = new GregorianCalendar();
        cal.set(Calendar.YEAR, 2007);
        cal.set(Calendar.MONTH, 12 - 1);
        cal.set(Calendar.DAY_OF_MONTH, 11);
        cal.set(Calendar.HOUR_OF_DAY, 12);
        cal.set(Calendar.MINUTE, 31);
        cal.set(Calendar.SECOND, 53);
        cal.getTime();
        cal.setTimeZone(TimeZone.getTimeZone("GMT"));
        cal.getTime();
        int year = cal.get(Calendar.YEAR);
        int month = cal.get(Calendar.MONTH) + 1;
        int day = cal.get(Calendar.DAY_OF_MONTH);
        int hour = cal.get(Calendar.HOUR_OF_DAY);
        int minute = cal.get(Calendar.MINUTE);
        int second = cal.get(Calendar.SECOND);
        String expectedTime = year + "-" + month + "-" + day + "T" + hour + ":" + minute + ":" + second + ".000Z";
        assertEquals(expectedTime, TimeUtil.formatToGMT(time));
    }
}
